"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GhApiNotifierPlugin = void 0;
const path_1 = __importDefault(require("path"));
const reg_suit_util_1 = require("reg-suit-util");
const tiny_commit_walker_1 = require("tiny-commit-walker");
const create_comment_1 = require("./create-comment");
const gh_gql_client_1 = require("./gh-gql-client");
class GhApiNotifierPlugin {
    constructor() {
        this.name = "reg-notify-github-with-api-plugin";
    }
    init(config) {
        this._logger = config.logger;
        this._owner = config.options.owner;
        this._repository = config.options.repository;
        this._githubUrl = config.options.githubUrl || "https://api.github.com/graphql";
        this._token = config.options.privateToken;
        this._repo = new tiny_commit_walker_1.Repository(path_1.default.join(reg_suit_util_1.fsUtil.prjRootDir(".git"), ".git"));
        this._shortDescription = config.options.shortDescription || false;
        this._ref = config.options.ref;
    }
    notify(params) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this._token) {
                this._logger.warn("GitHub private access token is needed. Check plugins config.");
                return;
            }
            if (!this._owner) {
                this._logger.warn("'owner' parameter is needed. Check plugins config.");
                return;
            }
            if (!this._repository) {
                this._logger.warn("'repository' parameter is needed. Check plugins config.");
                return;
            }
            const commentBody = (0, create_comment_1.createCommentBody)({
                reportUrl: params.reportUrl,
                passedItemsCount: params.comparisonResult.passedItems.length,
                failedItemsCount: params.comparisonResult.diffItems.length,
                newItemsCount: params.comparisonResult.newItems.length,
                deletedItemsCount: params.comparisonResult.deletedItems.length,
                shortDescription: this._shortDescription,
            });
            const client = new gh_gql_client_1.GhGqlClient(this._token, this._githubUrl);
            let branchName = undefined;
            if (this._ref) {
                if (!this._ref.startsWith("refs/heads/")) {
                    this._logger.warn(`ref option does not start with 'refs/heads': "${this._ref}"`);
                    return;
                }
                branchName = this._ref.replace(/^refs\/heads\//, "");
            }
            else {
                const head = this._repo.readHeadSync();
                if (head.type !== "branch" || !head.branch) {
                    this._logger.warn("Can't detect branch name.");
                    return;
                }
                branchName = head.branch.name;
            }
            if (!branchName) {
                this._logger.warn("Can't detect branch name.");
                return;
            }
            yield client.postCommentToPr({
                owner: this._owner,
                repository: this._repository,
                branchName,
                body: commentBody,
            });
        });
    }
}
exports.GhApiNotifierPlugin = GhApiNotifierPlugin;
//# sourceMappingURL=gh-api-notifier-plugin.js.map